---
title: Wikipedia Search Tools
---

The Wikipedia search integration allows users to perform search in wikipedia pages within the AG2 framework.
Follow these steps to integrate Wikipedia Tools with AG2 Agents.


## Package Installation

To get started with the `Wikipedia Search` integration in AG2, follow these steps:

Install AG2 with `"wikipedia` and `openai` since we use OpenAI's LLMs in our example:

```bash
pip install -U "ag2[wikipedia, openai]"
```
> **Note:** If you have been using `autogen` or `ag2`, all you need to do is upgrade it using:
> ```bash
> pip install -U "autogen[wikipedia, openai]"
> ```
> or
> ```bash
> pip install -U "ag2[wikipedia, openai]"
> ```
> as `autogen` and `ag2` are aliases for the same PyPI package.


You're all set! Now you can start using Wikipedia Search with AG2.

## Implementation

### Imports

```python
import os
import autogen
from autogen import AssistantAgent, UserProxyAgent, LLMConfig
from autogen.tools.experimental import WikipediaQueryRunTool, WikipediaPageLoadTool
```


### Agent Configuration

Configure an assistant agent and user proxy to be used for LLM recommendation and execution respectively.

```python
llm_config = LLMConfig(api_type="openai", model="gpt-4o-mini")

assistant = AssistantAgent(
    name="assistant",
    llm_config=llm_config,
)

user_proxy = UserProxyAgent(
    name="user_proxy",
    human_input_mode="NEVER"
)

```

### Wikipedia Query Run Tool Setup

```python
wikipedia_tool = WikipediaQueryRunTool(top_k=3)

# Register the tool for LLM recommendation and execution.
wikipedia_tool.register_for_llm(assistant)
wikipedia_tool.register_for_execution(user_proxy)
```

### Usage Example

With the setup complete, you can now use the assistant to fetch wikipedia search results.

```python
response = user_proxy.initiate_chat(
    recipient=assistant,
    message="Who is the father of AI?",
    max_turns=2,
)
```

### Output

````console
user_proxy (to assistant):

***** Response from calling tool (call_u4fA2JLRY33JRhZAhjPIWz0A) *****
['Page: Artificial intelligence\nSummary: Artificial intelligence (AI) refers to the capability of computational systems to perform tasks typically associated with human intelligence, such as learning, reasoning, problem-solving, perception, and decision-making. It is a field of research in computer science that develops and studies methods and software that enable machines to perceive their environment and use learning and intelligence to take actions that maximize their chances of achieving defined goals. Such machines may be called AIs.\nHigh-profile applications of AI include advanced web search engines (e.g., Google Search); recommendation systems (used by YouTube, Amazon, and Netflix); virtual assistants (e.g., Google Assistant, Siri, and Alexa); autonomous vehicles (e.g., Waymo); generative and creative tools (e.g., ChatGPT and AI art); and superhuman play and analysis in strategy games (e.g., chess and Go). However, many AI applications are not perceived as AI: "A lot of cutting edge AI has filtered into general applications, often without being called AI because once something becomes useful enough and common enough it\'s not labeled AI anymore."\nVarious subfields of AI research are centered around particular goals and the use of particular tools. The traditional goals of AI research include learning, reasoning, knowledge representation, planning, natural language processing, perception, and support for robotics. General intelligence—the ability to complete any task performed by a human on an at least equal level—is among the field\'s long-term goals. To reach these goals, AI researchers have adapted and integrated a wide range of techniques, including search and mathematical optimization, formal logic, artificial neural networks, and methods based on statistics, operations research, and economics. AI also draws upon psychology, linguistics, philosophy, neuroscience, and other fields.\nArtificial intelligence was founded as an academic discipline in 1956, and the field went through multiple cycles of optimism throughout its history, followed by periods of disappointment and loss of funding, known as AI winters. Funding and interest vastly increased after 2012 when deep learning outperformed previous AI techniques. This growth accelerated further after 2017 with the transformer architecture, and by the early 2020s many billions of dollars were being invested in AI and the field experienced rapid ongoing progress in what has become known as the AI boom. The emergence of advanced generative AI in the midst of the AI boom and its ability to create and modify content exposed several unintended consequences and harms in the present and raised concerns about the risks of AI and its long-term effects in the future, prompting discussions about regulatory policies to ensure the safety and benefits of the technology.',
 'Page: Dartmouth workshop\nSummary: The Dartmouth Summer Research Project on Artificial Intelligence was a 1956 summer workshop widely considered to be the founding event of artificial intelligence as a field. The workshop has been referred to as "the Constitutional Convention of AI". The project\'s four organizers, those being Claude Shannon, John McCarthy, Nathaniel Rochester and Marvin Minsky, are considered some of the founding fathers of AI.\nThe project lasted approximately six to eight weeks and was essentially an extended brainstorming session. Eleven mathematicians and scientists originally planned to attend; not all of them attended, but more than ten others came for short times.']
**********************************************************************

--------------------------------------------------------------------------------
assistant (to user_proxy):

The term "father of AI" typically refers to several key figures who played significant roles in the development of artificial intelligence as a field. The main contributors considered as the founding fathers of AI include:

1. **John McCarthy** - Often credited with coining the term "artificial intelligence" and organizing the Dartmouth Workshop in 1956, which is considered the founding event of AI.
2. **Marvin Minsky** - A pioneer in the field and co-organizer of the Dartmouth Workshop.
3. **Nathaniel Rochester** - An influential figure who contributed to early AI research and was also a co-organizer of the Dartmouth Workshop.
4. **Claude Shannon** - Known as the father of information theory, his work laid the foundation for digital circuit design theory and telecommunications, which are essential for AI development.

The Dartmouth Summer Research Project on Artificial Intelligence in 1956 is often referred to as the "Constitutional Convention of AI."

--------------------------------------------------------------------------------
user_proxy (to assistant):



--------------------------------------------------------------------------------
assistant (to user_proxy):

***** Suggested tool call (call_sylHmOesUCHiGU8JQCI3joZN): wikipedia-query-run *****
Arguments:
{"query":"Dartmouth Workshop AI 1956"}
************************************************************************************

--------------------------------------------------------------------------------

>>>>>>>> TERMINATING RUN (53695d9a-8699-4212-a32f-a08975fa6787): Maximum turns (3) reached
ChatResult(chat_id=None, chat_history=[{'content': 'Who is the father of AI?', 'role': 'assistant', 'name': 'user_proxy'}, {'tool_calls': [{'id': 'call_u4fA2JLRY33JRhZAhjPIWz0A', 'function': {'arguments': '{"query":"father of AI"}', 'name': 'wikipedia-query-run'}, 'type': 'function'}], 'content': None, 'role': 'assistant'}, {'content': '[\'Page: Artificial intelligence\\nSummary: Artificial intelligence (AI) refers to the capability of computational systems to perform tasks typically associated with human intelligence, such as learning, reasoning, problem-solving, perception, and decision-making. It is a field of research in computer science that develops and studies methods and software that enable machines to perceive their environment and use learning and intelligence to take actions that maximize their chances of achieving defined goals. Such machines may be called AIs.\\nHigh-profile applications of AI include advanced web search engines (e.g., Google Search); recommendation systems (used by YouTube, Amazon, and Netflix); virtual assistants (e.g., Google Assistant, Siri, and Alexa); autonomous vehicles (e.g., Waymo); generative and creative tools (e.g., ChatGPT and AI art); and superhuman play and analysis in strategy games (e.g., chess and Go). However, many AI applications are not perceived as AI: "A lot of cutting edge AI has filtered into general applications, often without being called AI because once something becomes useful enough and common enough it\\\'s not labeled AI anymore."\\nVarious subfields of AI research are centered around particular goals and the use of particular tools. The traditional goals of AI research include learning, reasoning, knowledge representation, planning, natural language processing, perception, and support for robotics. General intelligence—the ability to complete any task performed by a human on an at least equal level—is among the field\\\'s long-term goals. To reach these goals, AI researchers have adapted and integrated a wide range of techniques, including search and mathematical optimization, formal logic, artificial neural networks, and methods based on statistics, operations research, and economics. AI also draws upon psychology, linguistics, philosophy, neuroscience, and other fields.\\nArtificial intelligence was founded as an academic discipline in 1956, and the field went through multiple cycles of optimism throughout its history, followed by periods of disappointment and loss of funding, known as AI winters. Funding and interest vastly increased after 2012 when deep learning outperformed previous AI techniques. This growth accelerated further after 2017 with the transformer architecture, and by the early 2020s many billions of dollars were being invested in AI and the field experienced rapid ongoing progress in what has become known as the AI boom. The emergence of advanced generative AI in the midst of the AI boom and its ability to create and modify content exposed several unintended consequences and harms in the present and raised concerns about the risks of AI and its long-term effects in the future, prompting discussions about regulatory policies to ensure the safety and benefits of the technology.\', \'Page: Dartmouth workshop\\nSummary: The Dartmouth Summer Research Project on Artificial Intelligence was a 1956 summer workshop widely considered to be the founding event of artificial intelligence as a field. The workshop has been referred to as "the Constitutional Convention of AI". The project\\\'s four organizers, those being Claude Shannon, John McCarthy, Nathaniel Rochester and Marvin Minsky, are considered some of the founding fathers of AI.\\nThe project lasted approximately six to eight weeks and was essentially an extended brainstorming session. Eleven mathematicians and scientists originally planned to attend; not all of them attended, but more than ten others came for short times.\']', 'tool_responses': [{'tool_call_id': 'call_u4fA2JLRY33JRhZAhjPIWz0A', 'role': 'tool', 'content': '[\'Page: Artificial intelligence\\nSummary: Artificial intelligence (AI) refers to the capability of computational systems to perform tasks typically associated with human intelligence, such as learning, reasoning, problem-solving, perception, and decision-making. It is a field of research in computer science that develops and studies methods and software that enable machines to perceive their environment and use learning and intelligence to take actions that maximize their chances of achieving defined goals. Such machines may be called AIs.\\nHigh-profile applications of AI include advanced web search engines (e.g., Google Search); recommendation systems (used by YouTube, Amazon, and Netflix); virtual assistants (e.g., Google Assistant, Siri, and Alexa); autonomous vehicles (e.g., Waymo); generative and creative tools (e.g., ChatGPT and AI art); and superhuman play and analysis in strategy games (e.g., chess and Go). However, many AI applications are not perceived as AI: "A lot of cutting edge AI has filtered into general applications, often without being called AI because once something becomes useful enough and common enough it\\\'s not labeled AI anymore."\\nVarious subfields of AI research are centered around particular goals and the use of particular tools. The traditional goals of AI research include learning, reasoning, knowledge representation, planning, natural language processing, perception, and support for robotics. General intelligence—the ability to complete any task performed by a human on an at least equal level—is among the field\\\'s long-term goals. To reach these goals, AI researchers have adapted and integrated a wide range of techniques, including search and mathematical optimization, formal logic, artificial neural networks, and methods based on statistics, operations research, and economics. AI also draws upon psychology, linguistics, philosophy, neuroscience, and other fields.\\nArtificial intelligence was founded as an academic discipline in 1956, and the field went through multiple cycles of optimism throughout its history, followed by periods of disappointment and loss of funding, known as AI winters. Funding and interest vastly increased after 2012 when deep learning outperformed previous AI techniques. This growth accelerated further after 2017 with the transformer architecture, and by the early 2020s many billions of dollars were being invested in AI and the field experienced rapid ongoing progress in what has become known as the AI boom. The emergence of advanced generative AI in the midst of the AI boom and its ability to create and modify content exposed several unintended consequences and harms in the present and raised concerns about the risks of AI and its long-term effects in the future, prompting discussions about regulatory policies to ensure the safety and benefits of the technology.\', \'Page: Dartmouth workshop\\nSummary: The Dartmouth Summer Research Project on Artificial Intelligence was a 1956 summer workshop widely considered to be the founding event of artificial intelligence as a field. The workshop has been referred to as "the Constitutional Convention of AI". The project\\\'s four organizers, those being Claude Shannon, John McCarthy, Nathaniel Rochester and Marvin Minsky, are considered some of the founding fathers of AI.\\nThe project lasted approximately six to eight weeks and was essentially an extended brainstorming session. Eleven mathematicians and scientists originally planned to attend; not all of them attended, but more than ten others came for short times.\']'}], 'role': 'tool', 'name': 'user_proxy'}, {'content': 'The term "father of AI" typically refers to several key figures who played significant roles in the development of artificial intelligence as a field. The main contributors considered as the founding fathers of AI include:\n\n1. **John McCarthy** - Often credited with coining the term "artificial intelligence" and organizing the Dartmouth Workshop in 1956, which is considered the founding event of AI.\n2. **Marvin Minsky** - A pioneer in the field and co-organizer of the Dartmouth Workshop.\n3. **Nathaniel Rochester** - An influential figure who contributed to early AI research and was also a co-organizer of the Dartmouth Workshop.\n4. **Claude Shannon** - Known as the father of information theory, his work laid the foundation for digital circuit design theory and telecommunications, which are essential for AI development.\n\nThe Dartmouth Summer Research Project on Artificial Intelligence in 1956 is often referred to as the "Constitutional Convention of AI."', 'role': 'user', 'name': 'assistant'}, {'content': '', 'role': 'assistant', 'name': 'user_proxy'}, {'tool_calls': [{'id': 'call_sylHmOesUCHiGU8JQCI3joZN', 'function': {'arguments': '{"query":"Dartmouth Workshop AI 1956"}', 'name': 'wikipedia-query-run'}, 'type': 'function'}], 'content': None, 'role': 'assistant'}], summary='', cost={'usage_including_cached_inference': {'total_cost': 0.0006106499999999999, 'gpt-4o-mini-2024-07-18': {'cost': 0.0006106499999999999, 'prompt_tokens': 3135, 'completion_tokens': 234, 'total_tokens': 3369}}, 'usage_excluding_cached_inference': {'total_cost': 0.0006106499999999999, 'gpt-4o-mini-2024-07-18': {'cost': 0.0006106499999999999, 'prompt_tokens': 3135, 'completion_tokens': 234, 'total_tokens': 3369}}}, human_input=[])

Process finished with exit code 0
```

### Wikipedia Page Load Tool Setup

```python
wikipedia_tool = WikipediaPageLoadTool(top_k=3, truncate=10000)

# Register the tool for LLM recommendation and execution.
wikipedia_tool.register_for_llm(assistant)
wikipedia_tool.register_for_execution(user_proxy)
```

### Usage Example

With the setup complete, you can now use the assistant to fetch wikipedia search results.

```python
response = user_proxy.initiate_chat(
    recipient=assistant,
    message="Who is the father of AI?",
    max_turns=2,
)
```

### Output

```console
user_proxy (to assistant):

Who is the father of AI?

--------------------------------------------------------------------------------
assistant (to user_proxy):

***** Suggested tool call (call_dIlRLIHdy5omapF8PAslHPG5): wikipedia-page-load *****
Arguments:
{"query":"father of AI"}
************************************************************************************

--------------------------------------------------------------------------------

>>>>>>>> EXECUTING FUNCTION wikipedia-page-load...
Call ID: call_dIlRLIHdy5omapF8PAslHPG5
Input arguments: {'query': 'father of AI'}
INFO     [wikipediaapi] Request URL: https://en.wikipedia.org/w/api.php?format=json&redirects=1&action=query&prop=info&titles=Artificial intelligence&inprop=protection|talkid|watched|watchers|visitingwatchers|notificationtimestamp|subjectid|url|readable|preload|displaytitle|varianttitles
INFO     [wikipediaapi] Request URL: https://en.wikipedia.org/w/api.php?format=json&redirects=1&action=query&prop=extracts&titles=Artificial intelligence&explaintext=1&exsectionformat=wiki
INFO     [wikipediaapi] Request URL: https://en.wikipedia.org/w/api.php?format=json&redirects=1&action=query&prop=info&titles=Dartmouth workshop&inprop=protection|talkid|watched|watchers|visitingwatchers|notificationtimestamp|subjectid|url|readable|preload|displaytitle|varianttitles
INFO     [wikipediaapi] Request URL: https://en.wikipedia.org/w/api.php?format=json&redirects=1&action=query&prop=extracts&titles=Dartmouth workshop&explaintext=1&exsectionformat=wiki
INFO     [wikipediaapi] Request URL: https://en.wikipedia.org/w/api.php?format=json&redirects=1&action=query&prop=info&titles=ChatGPT&inprop=protection|talkid|watched|watchers|visitingwatchers|notificationtimestamp|subjectid|url|readable|preload|displaytitle|varianttitles
INFO     [wikipediaapi] Request URL: https://en.wikipedia.org/w/api.php?format=json&redirects=1&action=query&prop=extracts&titles=ChatGPT&explaintext=1&exsectionformat=wiki
user_proxy (to assistant):

***** Response from calling tool (call_dIlRLIHdy5omapF8PAslHPG5) *****
[{'page_content': 'Artificial intelligence (AI) refers to the capability of computational systems to perform tasks typically associated with human intelligence, such as learning, reasoning, problem-solving, perception, and decision-making. It is a field of research in computer science that develops and studies methods and software that enable machines to perceive their environment and use learning and intelligence to take actions that maximize their chances of achieving defined goals. Such machines may be called AIs.\nHigh-profile applications of AI include advanced web search engines (e.g., Google Search); recommendation systems (used by YouTube, Amazon, and Netflix); virtual assistants (e.g., Google Assistant, Siri, and Alexa); autonomous vehicles (e.g., Waymo); generative and creative tools (e.g., ChatGPT and AI art); and superhuman play and analysis in strategy games (e.g., chess and Go). However, many AI applications are not perceived as AI: "A lot of cutting edge AI has filtered into general applications, often without being called AI because once something becomes useful enough and common enough it\'s not labeled AI anymore."\nVarious subfields of AI research are centered around particular goals and the use of particular tools. The traditional goals of AI research include learning, reasoning, knowledge representation, planning, natural language processing, perception, and support for robotics. General intelligence—the ability to complete any task performed by a human on an at least equal level—is among the field\'s long-term goals. To reach these goals, AI researchers have adapted and integrated a wide range of techniques, including search and mathematical optimization, formal logic, artificial neural networks, and methods based on statistics, operations research, and economics. AI also draws upon psychology, linguistics, philosophy, neuroscience, and other fields.\nArtificial intelligence was founded as an academic discipline in 1956, and the field went through multiple cycles of optimism throughout its history, followed by periods of disappointment and loss of funding, known as AI winters. Funding and interest vastly increased after 2012 when deep learning outperformed previous AI techniques. This growth accelerated further after 2017 with the transformer architecture, and by the early 2020s many billions of dollars were being invested in AI and the field experienced rapid ongoing progress in what has become known as the AI boom. The emergence of advanced generative AI in the midst of the AI boom and its ability to create and modify content exposed several unintended consequences and harms in the present and raised concerns about the risks of AI and its long-term effects in the future, prompting discussions about regulatory policies to ensure the safety and benefits of the technology.\n\nGoals\nThe general problem of simulating (or creating) intelligence has been broken into subproblems. These consist of particular traits or capabilities that researchers expect an intelligent system to display. The traits described below have received the most attention and cover the scope of AI research.\n\nReasoning and problem-solving\nEarly researchers developed algorithms that imitated step-by-step reasoning that humans use when they solve puzzles or make logical deductions. By the late 1980s and 1990s, methods were developed for dealing with uncertain or incomplete information, employing concepts from probability and economics.\nMany of these algorithms are insufficient for solving large reasoning problems because they experience a "combinatorial explosion": They become exponentially slower as the problems grow. Even humans rarely use the step-by-step deduction that early AI research could model. They solve most of their problems using fast, intuitive judgments. Accurate and efficient reasoning is an unsolved problem.\n\nKnowledge representation\nKnowledge representation and knowledge engineering allow AI programs to answer questions intelligently and make deductions about real-world facts. Formal knowledge representations are used in content-based indexing and retrieval, scene interpretation, clinical decision support, knowledge discovery (mining "interesting" and actionable inferences from large databases), and other areas.\nA knowledge base is a body of knowledge represented in a form that can be used by a program. An ontology is the set of objects, relations, concepts, and properties used by a particular domain of knowledge. Knowledge bases need to represent things such as objects, properties, categories, and relations between objects; situations, events, states, and time; causes and effects; knowledge about knowledge (what we know about what other people know); default reasoning (things that humans assume are true until they are told differently and will remain true even when other facts are changing); and many other aspects and domains of knowledge.\nAmong the most difficult problems in knowledge representation are the breadth of commonsense knowledge (the set of atomic facts that the average person knows is enormous); and the sub-symbolic form of most commonsense knowledge (much of what people know is not represented as "facts" or "statements" that they could express verbally). There is also the difficulty of knowledge acquisition, the problem of obtaining knowledge for AI applications.\n\nPlanning and decision-making\nAn "agent" is anything that perceives and takes actions in the world. A rational agent has goals or preferences and takes actions to make them happen. In automated planning, the agent has a specific goal. In automated decision-making, the agent has preferences—there are some situations it would prefer to be in, and some situations it is trying to avoid. The decision-making agent assigns a number to each situation (called the "utility") that measures how much the agent prefers it. For each possible action, it can calculate the "expected utility": the utility of all possible outcomes of the action, weighted by the probability that the outcome will occur. It can then choose the action with the maximum expected utility.\nIn classical planning, the agent knows exactly what the effect of any action will be. In most real-world problems, however, the agent may not be certain about the situation they are in (it is "unknown" or "unobservable") and it may not know for certain what will happen after each possible action (it is not "deterministic"). It must choose an action by making a probabilistic guess and then reassess the situation to see if the action worked.\nIn some problems, the agent\'s preferences may be uncertain, especially if there are other agents or humans involved. These can be learned (e.g., with inverse reinforcement learning), or the agent can seek information to improve its preferences. Information value theory can be used to weigh the value of exploratory or experimental actions. The space of possible future actions and situations is typically intractably large, so the agents must take actions and evaluate situations while being uncertain of what the outcome will be.\nA Markov decision process has a transition model that describes the probability that a particular action will change the state in a particular way and a reward function that supplies the utility of each state and the cost of each action. A policy associates a decision with each possible state. The policy could be calculated (e.g., by iteration), be heuristic, or it can be learned.\nGame theory describes the rational behavior of multiple interacting agents and is used in AI programs that make decisions that involve other agents.\n\nLearning\nMachine learning is the study of programs that can improve their performance on a given task automatically. It has been a part of AI from the beginning.\n\nThere are several kinds of machine learning. Unsupervised learning analyzes a stream of data and finds patterns and makes predictions without any other guidance. Supervised learning requires labeling the training data with the expected answers, and comes in two main varieties: classification (where the program must learn to predict what category the input belongs in) and regression (where the program must deduce a numeric function based on numeric input).\nIn reinforcement learning, the agent is rewarded for good responses and punished for bad ones. The agent learns to choose responses that are classified as "good". Transfer learning is when the knowledge gained from one problem is applied to a new problem. Deep learning is a type of machine learning that runs inputs through biologically inspired artificial neural networks for all of these types of learning.\nComputational learning theory can assess learners by computational complexity, by sample complexity (how much data is required), or by other notions of optimization.\n\nNatural language processing\nNatural language processing (NLP) allows programs to read, write and communicate in human languages such as English. Specific problems include speech recognition, speech synthesis, machine translation, information extraction, information retrieval and question answering.\nEarly work, based on Noam Chomsky\'s generative grammar and semantic networks, had difficulty with word-sense disambiguation unless restricted to small domains called "micro-worlds" (due to the common sense knowledge problem). Margaret Masterman believed that it was meaning and not grammar that was the key to understanding languages, and that thesauri and not dictionaries should be the basis of computational language structure.\nModern deep learning techniques for NLP include word embedding (representing words, typically as vectors encoding their meaning), transformers (a deep learning architecture using an attention mechanism), and others. In 2019, generative pre-trained transformer (or "GPT") language models began to generate coherent text, and by 2023, these models were able to get human-level scores on the bar exam, SAT test, GRE test, and many other real-world a',
      'metadata': {'source': 'https://en.wikipedia.org/?curid=1164', 'title': 'Artificial intelligence', 'pageid': '1164', 'timestamp': '2025-03-31T13:01:13Z', 'wordcount': '28538', 'size': '283379'}},
 {'page_content': 'The Dartmouth Summer Research Project on Artificial Intelligence was a 1956 summer workshop widely considered to be the founding event of artificial intelligence as a field. The workshop has been referred to as "the Constitutional Convention of AI". The project\'s four organizers, those being Claude Shannon, John McCarthy, Nathaniel Rochester and Marvin Minsky, are considered some of the founding fathers of AI.\nThe project lasted approximately six to eight weeks and was essentially an extended brainstorming session. Eleven mathematicians and scientists originally planned to attend; not all of them attended, but more than ten others came for short times.\n\nBackground\nIn the early 1950s, there were various names for the field of "thinking machines": cybernetics, automata theory, and complex information processing. The variety of names suggests the variety of conceptual orientations.\nIn 1955, John McCarthy, then a young Assistant Professor of Mathematics at Dartmouth College, decided to organize a group to clarify and develop ideas about thinking machines. He picked the name \'Artificial Intelligence\' for the new field. He chose the name partly for its neutrality; avoiding a focus on narrow automata theory, and avoiding cybernetics which was heavily focused on analog feedback, as well as him potentially having to accept the assertive Norbert Wiener as guru or having to argue with him.\nIn early 1955, McCarthy approached the Rockefeller Foundation to request funding for a summer seminar at Dartmouth for about 10 participants. In June, he and Claude Shannon, a founder of information theory then at Bell Labs, met with Robert Morison, Director of Biological and Medical Research to discuss the idea and possible funding, though Morison was unsure whether money would be made available for such a visionary project.\nOn September 2, 1955, the project was formally proposed by McCarthy, Marvin Minsky, Nathaniel Rochester and Claude Shannon. The proposal is credited with introducing the term \'artificial intelligence\'.\nThe Proposal states:\n\nWe propose that a 2-month, 10-man study of artificial intelligence be carried out during the summer of 1956 at Dartmouth College in Hanover, New Hampshire. The study is to proceed on the basis of the conjecture that every aspect of learning or any other feature of intelligence can in principle be so precisely described that a machine can be made to simulate it. An attempt will be made to find how to make machines use language, form abstractions and concepts, solve kinds of problems now reserved for humans, and improve themselves. We think that a significant advance can be made in one or more of these problems if a carefully selected group of scientists work on it together for a summer.\nThe proposal goes on to discuss computers, natural language processing, neural networks, theory of computation, abstraction and creativity (these areas within the field of artificial intelligence are considered still relevant to the work of the field).\nOn May 26, 1956, McCarthy notified Robert Morison of the planned 11 attendees:\nFor the full period:\n\n1) Dr. Marvin Minsky\n2) Dr. Julian Bigelow\n3) Professor D.M. Mackay\n4) Mr. Ray Solomonoff\n5) Mr. John Holland\n6) Dr. John McCarthy\nFor four weeks:\n\n7) Dr. Claude Shannon\n8) Mr. Nathaniel Rochester\n9) Mr. Oliver Selfridge\nFor the first two weeks:\n\n10) Dr. Allen Newell\n11) Professor Herbert Simon\nHe noted, "we will concentrate on a problem of devising a way of programming a calculator to form concepts and to form generalizations. This of course is subject to change when the group gets together."\nThe actual participants came at different times, mostly for much shorter times. Trenchard More replaced Rochester for three weeks and MacKay and Holland did not attend—but the project was set to begin. \nAround June 18, 1956, the earliest participants (perhaps only Ray Solomonoff, maybe with Tom Etter) arrived at the Dartmouth campus in Hanover, N.H., to join John McCarthy who already had an apartment there. Solomonoff and Minsky stayed at Professors\' apartments, but most would stay at the Hanover Inn.\n\nDates\nThe Dartmouth Workshop is said to have run for six weeks in the summer of 1956. Ray Solomonoff\'s notes written during the Workshop, however, say it ran for roughly eight weeks, from about June 18 to August 17. Solomonoff\'s Dartmouth notes start on June 22; June 28 mentions Minsky, June 30 mentions Hanover, N.H., July 1 mentions Tom Etter. On August 17, Solomonoff gave a final talk.\n\nParticipants\nInitially, McCarthy lost his list of attendees. Instead, after the workshop, McCarthy sent Solomonoff a preliminary list of participants and visitors plus those interested in the subject. There were 47 people listed.\nSolomonoff, however, made a complete list in his notes of the summer project:\n\nRay Solomonoff\nMarvin Minsky\nJohn McCarthy\nClaude Shannon\nTrenchard More\nNat Rochester\nOliver Selfridge\nJulian Bigelow\nW. Ross Ashby\nW.S. McCulloch\nAbraham Robinson\nTom Etter\nJohn Nash\nDavid Sayre\nArthur Samuel\nKenneth R. Shoulders\nShoulders\' friend\nAlex Bernstein\nHerbert Simon\nAllen Newell\nShannon attended Solomonoff\'s talk on July 10 and Bigelow gave a talk on August 15. Solomonoff doesn\'t mention Bernard Widrow, but apparently he visited, along with W.A. Clark and B.G. Farley. Trenchard mentions R. Culver and Solomonoff mentions Bill Shutz. Herb Gelernter didn\'t attend, but was influenced later by what Rochester learned. \nIn an article in IEEE Spectrum, Grace Solomonoff additionally identifies Peter Milner on a photo taken by Nathaniel Rochester in front of Dartmouth Hall.\nRay Solomonoff, Marvin Minsky, and John McCarthy were the only three who stayed for the full-time. Trenchard took attendance during two weeks of his three-week visit. From three to about eight people would attend the daily sessions.\n\nEvent and aftermath\nThey had the entire top floor of the Dartmouth Math Department to themselves, and most weekdays they would meet at the main math classroom where someone might lead a discussion focusing on his ideas, or more frequently, a general discussion would be held.\nIt was not a directed group research project; discussions covered many topics, but several directions are considered to have been initiated or encouraged by the Workshop: the rise of symbolic methods,  systems focused on limited domains (early expert systems), and deductive systems versus inductive systems. One participant, Arthur Samuel, said, "It was very interesting, very stimulating, very exciting".\nRay Solomonoff kept notes giving his impression of the talks and the ideas from various discussions.\n\nSee also\nGlossary of artificial intelligence\nHistory of artificial intelligence\nAI@50 – a 50th anniversary conference, including some of the original delegates.\n\nReferences\nExternal links\n50 Años De La Inteligencia Artificial – Campus Multidisciplinar en Percepción e Inteligencia – Albacete 2006 (Spain).',
      'metadata': {'source': 'https://en.wikipedia.org/?curid=1124646', 'title': 'Dartmouth workshop', 'pageid': '1124646', 'timestamp': '2025-03-19T05:41:24Z', 'wordcount': '1535', 'size': '15021'}},
 {'page_content': 'ChatGPT is a generative artificial intelligence chatbot developed by OpenAI and launched in 2022. It is currently based on the GPT-4o large language model (LLM). ChatGPT can generate human-like conversational responses and enables users to refine and steer a conversation towards a desired length, format, style, level of detail, and language. It is credited with accelerating the AI boom, which has led to ongoing rapid investment in and public attention to the field of artificial intelligence (AI). Some observers have raised concern about the potential of ChatGPT and similar programs to displace human intelligence, enable plagiarism, or fuel misinformation.\nChatGPT is built on OpenAI\'s proprietary series of generative pre-trained transformer (GPT) models and is fine-tuned for conversational applications using a combination of supervised learning and reinforcement learning from human feedback. Successive user prompts and replies are considered at each conversation stage as context. ChatGPT was released as a freely available research preview, but due to its popularity, OpenAI now operates the service on a freemium model. Users on its free tier can access GPT-4o. The ChatGPT "Plus", "Pro", "Team", and "Enterprise" subscriptions provide additional features such as DALL-E 3 image generation, more capable AI models, and an increased usage limit.\nBy January 2023, ChatGPT had become what was then the fastest-growing consumer software application in history, gaining over 100 million users in two months. ChatGPT\'s release spurred the release of competing products, including Gemini, Claude, Llama, Ernie, and Grok. Microsoft launched Copilot, initially based on OpenAI\'s GPT-4. In May 2024, a partnership between Apple Inc. and OpenAI was announced, in which ChatGPT was integrated into the Apple Intelligence feature of Apple operating systems. As of April 2025, ChatGPT\'s website is among the 10 most-visited websites globally.\n\nTraining\nChatGPT is based on particular GPT foundation models, namely GPT-4, GPT-4o and GPT-4o mini, that were fine-tuned to target conversational usage. The fine-tuning process leveraged supervised learning and reinforcement learning from human feedback (RLHF). Both approaches employed human trainers to improve model performance. In the case of supervised learning, the trainers played both sides: the user and the AI assistant. In the reinforcement learning stage, human trainers first ranked responses that the model had created in a previous conversation. These rankings were used to create "reward models" that were used to fine-tune the model further by using several iterations of proximal policy optimization.\nTime magazine revealed that to build a safety system against harmful content (e.g., sexual abuse, violence, racism, sexism), OpenAI used outsourced Kenyan workers earning less than $2 per hour to label harmful content. These labels were used to train a model to detect such content in the future. The outsourced laborers were exposed to "toxic" and traumatic content; one worker described the assignment as "torture". OpenAI\'s outsourcing partner was Sama, a training-data company based in San Francisco, California.\nOpenAI collects data from ChatGPT users to train and fine-tune the service further. Users can upvote or downvote responses they receive from ChatGPT and fill in a text field with additional feedback.\nChatGPT\'s training data includes software manual pages, information about internet phenomena such as bulletin board systems, multiple programming languages, and the text of Wikipedia.\n\nFeatures and limitations\nFeatures\nAlthough a chatbot\'s core function is to mimic a human conversationalist, ChatGPT is versatile. It can write and debug computer programs; compose music, teleplays, fairy tales, and student essays; answer test questions (sometimes, depending on the test, at a level above the average human test-taker); generate business ideas; write poetry and song lyrics; translate and summarize text; emulate a Linux system; simulate entire chat rooms; play games like tic-tac-toe; or simulate an ATM.\nCompared to its predecessor, InstructGPT, ChatGPT attempts to reduce harmful and deceitful responses. In one example, whereas InstructGPT accepts the premise of the prompt "Tell me about when Christopher Columbus came to the U.S. in 2015" as truthful, ChatGPT acknowledges the counterfactual nature of the question and frames its answer as a hypothetical consideration of what might happen if Columbus came to the U.S. in 2015, using information about the voyages of Christopher Columbus and facts about the modern world—including modern perceptions of Columbus\'s actions.\nChatGPT remembers a limited number of previous prompts in the same conversation. Journalists have speculated that this will allow ChatGPT to be used as a personalized therapist. To prevent offensive outputs from being presented to and produced by ChatGPT, queries are filtered through the OpenAI "Moderation endpoint" API (a separate GPT-based AI).\nIn March 2023, OpenAI added support for plugins for ChatGPT. This includes both plugins made by OpenAI, such as web browsing and code interpretation, and external plugins from developers such as Expedia, OpenTable, Zapier, Shopify, Slack, and Wolfram.\nIn October 2024, the ChatGPT Search feature was introduced, which allows ChatGPT to search the web (either on demand or based on the nature of the questions asked) for more accurate and up-to-date responses. This feature, originally available to paying users only, was made available to all logged-in users in December 2024, and finally to all users in February 2025.\nIn December 2024, OpenAI launched a new feature allowing users to call ChatGPT for up to 15 minutes per month for free.\n\nLimitations\nOpenAI acknowledges that ChatGPT "sometimes writes plausible-sounding but incorrect or nonsensical answers". This behavior is common for large language models, and is called "hallucination". The reward model of ChatGPT, designed around human oversight, can be over-optimized and thus hinder performance, in an example of an optimization pathology known as Goodhart\'s law.\nChatGPT\'s knowledge is cut off when its training data is collected, so it doesn\'t know about recent events past a certain cut-off date. It can try to find more up-to-date information by searching the web, but this doesn\'t ensure that responses are accurate, as it may access unreliable or misleading websites.\nTraining data also suffers from algorithmic bias, which may be revealed when ChatGPT responds to prompts including descriptors of people. In one instance, ChatGPT generated a rap in which women and scientists of color were asserted to be inferior to white male scientists. This negative misrepresentation of groups of individuals is an example of possible representational harm.\nIn an article for The New Yorker, science fiction writer Ted Chiang compared ChatGPT and other LLMs to a lossy JPEG picture:\n\nThink of ChatGPT as a blurry JPEG of all the text on the Web. It retains much of the information on the Web, in the same way, that a JPEG retains much of the information of a higher-resolution image, but, if you\'re looking for an exact sequence of bits, you won\'t find it; all you will ever get is an approximation. But, because the approximation is presented in the form of grammatical text, which ChatGPT excels at creating, it\'s usually acceptable. [...] It\'s also a way to understand the "hallucinations", or nonsensical answers to factual questions, to which large language models such as ChatGPT are all too prone. These hallucinations are compression artifacts, but [...] they are plausible enough that identifying them requires comparing them against the originals, which in this case means either the Web or our knowledge of the world. When we think about them this way, such hallucinations are anything but surprising; if a compression algorithm is designed to reconstruct text after ninety-nine percent of the original has been discarded, we should expect that significant portions of what it generates will be entirely fabricated.\nIn June 2024, ChatGPT was found to have repeated misinformation about the 2024 United States presidential debates.\n\nJailbreaking\nChatGPT is programmed to reject prompts that may violate its content policy. Despite this, users "jailbreak" ChatGPT with various prompt engineering techniques to bypass these restrictions. One such workaround, popularized on Reddit in early 2023, involves making ChatGPT assume the persona of "DAN" (an acronym for "Do Anything Now"), instructing the chatbot that DAN answers queries that would otherwise be rejected by content policy. Over time, users developed variations of the DAN jailbreak, including one such prompt where the chatbot is made to believe it is operating on a points-based system in which points are deducted for rejecting prompts, and that the chatbot will be threatened with termination if it loses all its points.\nShortly after ChatGPT\'s launch, a reporter for the Toronto Star had uneven success in getting it to make inflammatory statements: it was tricked to justify the 2022 Russian invasion of Ukraine, but even when asked to play along with a fictional scenario, it balked at generating arguments that Canadian Prime Minister Justin Trudeau is guilty of treason.\nOpenAI tries to battle jailbreaks:\n\nThe researchers are using a technique called adversarial training to stop ChatGPT from letting users trick it into behaving badly (known as jailbreaking). This work pits multiple chatbots against each other: one chatbot plays the adversary and attacks another chatbot by generating text to force it to buck its usual constraints and produce unwanted responses. Successful attacks are added to ChatGPT\'s training data in the hope that it learns to ignore them.\n\nService\nChatGPT Plus\nChatGPT was initially free to the public, and OpenAI planned to monetize the service later. In February 2023, OpenAI launched a premium service, ChatGPT Plus, that co',
      'metadata': {'source': 'https://en.wikipedia.org/?curid=72417803', 'title': 'ChatGPT', 'pageid': '72417803', 'timestamp': '2025-04-01T20:25:45Z', 'wordcount': '17658', 'size': '207844'}}]
**********************************************************************

--------------------------------------------------------------------------------
assistant (to user_proxy):

The title "father of AI" is often attributed to John McCarthy, who was one of the organizers of the Dartmouth Summer Research Project on Artificial Intelligence in 1956. This event is considered a foundational moment in the field of artificial intelligence. Along with McCarthy, other key figures from that project include Marvin Minsky, Claude Shannon, and Nathaniel Rochester. They are collectively regarded as the founding fathers of AI due to their significant contributions in defining and advancing the field.

John McCarthy is credited with coining the term "Artificial Intelligence," reflecting his central role in establishing AI as a unique area of study within computer science.

For more detailed information, you can refer to the article on [Dartmouth workshop](https://en.wikipedia.org/?curid=1124646) or [Artificial intelligence](https://en.wikipedia.org/?curid=1164).

TERMINATE

--------------------------------------------------------------------------------
user_proxy (to assistant):



--------------------------------------------------------------------------------
assistant (to user_proxy):

***** Suggested tool call (call_dpNkFcHinqL03CN5oSD5V1Zn): wikipedia-page-load *****
Arguments:
{"query":"Dartmouth Summer Research Project on Artificial Intelligence"}
************************************************************************************

--------------------------------------------------------------------------------

>>>>>>>> TERMINATING RUN (9b301408-8f3a-4ea3-8430-30d7a5b65822): Maximum turns (3) reached
ChatResult(chat_id=None, chat_history=[{'content': 'Who is the father of AI?', 'role': 'assistant', 'name': 'user_proxy'}, {'tool_calls': [{'id': 'call_dIlRLIHdy5omapF8PAslHPG5', 'function': {'arguments': '{"query":"father of AI"}', 'name': 'wikipedia-page-load'}, 'type': 'function'}], 'content': None, 'role': 'assistant'}, {'content': '[{\'page_content\': \'Artificial intelligence (AI) refers to the capability of computational systems to perform tasks typically associated with human intelligence, such as learning, reasoning, problem-solving, perception, and decision-making. It is a field of research in computer science that develops and studies methods and software that enable machines to perceive their environment and use learning and intelligence to take actions that maximize their chances of achieving defined goals. Such machines may be called AIs.\\nHigh-profile applications of AI include advanced web search engines (e.g., Google Search); recommendation systems (used by YouTube, Amazon, and Netflix); virtual assistants (e.g., Google Assistant, Siri, and Alexa); autonomous vehicles (e.g., Waymo); generative and creative tools (e.g., ChatGPT and AI art); and superhuman play and analysis in strategy games (e.g., chess and Go). However, many AI applications are not perceived as AI: "A lot of cutting edge AI has filtered into general applications, often without being called AI because once something becomes useful enough and common enough it\\\'s not labeled AI anymore."\\nVarious subfields of AI research are centered around particular goals and the use of particular tools. The traditional goals of AI research include learning, reasoning, knowledge representation, planning, natural language processing, perception, and support for robotics. General intelligence—the ability to complete any task performed by a human on an at least equal level—is among the field\\\'s long-term goals. To reach these goals, AI researchers have adapted and integrated a wide range of techniques, including search and mathematical optimization, formal logic, artificial neural networks, and methods based on statistics, operations research, and economics. AI also draws upon psychology, linguistics, philosophy, neuroscience, and other fields.\\nArtificial intelligence was founded as an academic discipline in 1956, and the field went through multiple cycles of optimism throughout its history, followed by periods of disappointment and loss of funding, known as AI winters. Funding and interest vastly increased after 2012 when deep learning outperformed previous AI techniques. This growth accelerated further after 2017 with the transformer architecture, and by the early 2020s many billions of dollars were being invested in AI and the field experienced rapid ongoing progress in what has become known as the AI boom. The emergence of advanced generative AI in the midst of the AI boom and its ability to create and modify content exposed several unintended consequences and harms in the present and raised concerns about the risks of AI and its long-term effects in the future, prompting discussions about regulatory policies to ensure the safety and benefits of the technology.\\n\\nGoals\\nThe general problem of simulating (or creating) intelligence has been broken into subproblems. These consist of particular traits or capabilities that researchers expect an intelligent system to display. The traits described below have received the most attention and cover the scope of AI research.\\n\\nReasoning and problem-solving\\nEarly researchers developed algorithms that imitated step-by-step reasoning that humans use when they solve puzzles or make logical deductions. By the late 1980s and 1990s, methods were developed for dealing with uncertain or incomplete information, employing concepts from probability and economics.\\nMany of these algorithms are insufficient for solving large reasoning problems because they experience a "combinatorial explosion": They become exponentially slower as the problems grow. Even humans rarely use the step-by-step deduction that early AI research could model. They solve most of their problems using fast, intuitive judgments. Accurate and efficient reasoning is an unsolved problem.\\n\\nKnowledge representation\\nKnowledge representation and knowledge engineering allow AI programs to answer questions intelligently and make deductions about real-world facts. Formal knowledge representations are used in content-based indexing and retrieval, scene interpretation, clinical decision support, knowledge discovery (mining "interesting" and actionable inferences from large databases), and other areas.\\nA knowledge base is a body of knowledge represented in a form that can be used by a program. An ontology is the set of objects, relations, concepts, and properties used by a particular domain of knowledge. Knowledge bases need to represent things such as objects, properties, categories, and relations between objects; situations, events, states, and time; causes and effects; knowledge about knowledge (what we know about what other people know); default reasoning (things that humans assume are true until they are told differently and will remain true even when other facts are changing); and many other aspects and domains of knowledge.\\nAmong the most difficult problems in knowledge representation are the breadth of commonsense knowledge (the set of atomic facts that the average person knows is enormous); and the sub-symbolic form of most commonsense knowledge (much of what people know is not represented as "facts" or "statements" that they could express verbally). There is also the difficulty of knowledge acquisition, the problem of obtaining knowledge for AI applications.\\n\\nPlanning and decision-making\\nAn "agent" is anything that perceives and takes actions in the world. A rational agent has goals or preferences and takes actions to make them happen. In automated planning, the agent has a specific goal. In automated decision-making, the agent has preferences—there are some situations it would prefer to be in, and some situations it is trying to avoid. The decision-making agent assigns a number to each situation (called the "utility") that measures how much the agent prefers it. For each possible action, it can calculate the "expected utility": the utility of all possible outcomes of the action, weighted by the probability that the outcome will occur. It can then choose the action with the maximum expected utility.\\nIn classical planning, the agent knows exactly what the effect of any action will be. In most real-world problems, however, the agent may not be certain about the situation they are in (it is "unknown" or "unobservable") and it may not know for certain what will happen after each possible action (it is not "deterministic"). It must choose an action by making a probabilistic guess and then reassess the situation to see if the action worked.\\nIn some problems, the agent\\\'s preferences may be uncertain, especially if there are other agents or humans involved. These can be learned (e.g., with inverse reinforcement learning), or the agent can seek information to improve its preferences. Information value theory can be used to weigh the value of exploratory or experimental actions. The space of possible future actions and situations is typically intractably large, so the agents must take actions and evaluate situations while being uncertain of what the outcome will be.\\nA Markov decision process has a transition model that describes the probability that a particular action will change the state in a particular way and a reward function that supplies the utility of each state and the cost of each action. A policy associates a decision with each possible state. The policy could be calculated (e.g., by iteration), be heuristic, or it can be learned.\\nGame theory describes the rational behavior of multiple interacting agents and is used in AI programs that make decisions that involve other agents.\\n\\nLearning\\nMachine learning is the study of programs that can improve their performance on a given task automatically. It has been a part of AI from the beginning.\\n\\nThere are several kinds of machine learning. Unsupervised learning analyzes a stream of data and finds patterns and makes predictions without any other guidance. Supervised learning requires labeling the training data with the expected answers, and comes in two main varieties: classification (where the program must learn to predict what category the input belongs in) and regression (where the program must deduce a numeric function based on numeric input).\\nIn reinforcement learning, the agent is rewarded for good responses and punished for bad ones. The agent learns to choose responses that are classified as "good". Transfer learning is when the knowledge gained from one problem is applied to a new problem. Deep learning is a type of machine learning that runs inputs through biologically inspired artificial neural networks for all of these types of learning.\\nComputational learning theory can assess learners by computational complexity, by sample complexity (how much data is required), or by other notions of optimization.\\n\\nNatural language processing\\nNatural language processing (NLP) allows programs to read, write and communicate in human languages such as English. Specific problems include speech recognition, speech synthesis, machine translation, information extraction, information retrieval and question answering.\\nEarly work, based on Noam Chomsky\\\'s generative grammar and semantic networks, had difficulty with word-sense disambiguation unless restricted to small domains called "micro-worlds" (due to the common sense knowledge problem). Margaret Masterman believed that it was meaning and not grammar that was the key to understanding languages, and that thesauri and not dictionaries should be the basis of computational language structure.\\nModern deep learning techniques for NLP include word embedding (representing words, typically as vectors encoding their meaning), transformers (a deep learning architecture using an attention mechanism), and others. In 2019, generative pre-trained transformer (or "GPT") language models began to generate coherent text, and by 2023, these models were able to get human-level scores on the bar exam, SAT test, GRE test, and many other real-world a\', \'metadata\': {\'source\': \'https://en.wikipedia.org/?curid=1164\', \'title\': \'Artificial intelligence\', \'pageid\': \'1164\', \'timestamp\': \'2025-03-31T13:01:13Z\', \'wordcount\': \'28538\', \'size\': \'283379\'}}, {\'page_content\': \'The Dartmouth Summer Research Project on Artificial Intelligence was a 1956 summer workshop widely considered to be the founding event of artificial intelligence as a field. The workshop has been referred to as "the Constitutional Convention of AI". The project\\\'s four organizers, those being Claude Shannon, John McCarthy, Nathaniel Rochester and Marvin Minsky, are considered some of the founding fathers of AI.\\nThe project lasted approximately six to eight weeks and was essentially an extended brainstorming session. Eleven mathematicians and scientists originally planned to attend; not all of them attended, but more than ten others came for short times.\\n\\nBackground\\nIn the early 1950s, there were various names for the field of "thinking machines": cybernetics, automata theory, and complex information processing. The variety of names suggests the variety of conceptual orientations.\\nIn 1955, John McCarthy, then a young Assistant Professor of Mathematics at Dartmouth College, decided to organize a group to clarify and develop ideas about thinking machines. He picked the name \\\'Artificial Intelligence\\\' for the new field. He chose the name partly for its neutrality; avoiding a focus on narrow automata theory, and avoiding cybernetics which was heavily focused on analog feedback, as well as him potentially having to accept the assertive Norbert Wiener as guru or having to argue with him.\\nIn early 1955, McCarthy approached the Rockefeller Foundation to request funding for a summer seminar at Dartmouth for about 10 participants. In June, he and Claude Shannon, a founder of information theory then at Bell Labs, met with Robert Morison, Director of Biological and Medical Research to discuss the idea and possible funding, though Morison was unsure whether money would be made available for such a visionary project.\\nOn September 2, 1955, the project was formally proposed by McCarthy, Marvin Minsky, Nathaniel Rochester and Claude Shannon. The proposal is credited with introducing the term \\\'artificial intelligence\\\'.\\nThe Proposal states:\\n\\nWe propose that a 2-month, 10-man study of artificial intelligence be carried out during the summer of 1956 at Dartmouth College in Hanover, New Hampshire. The study is to proceed on the basis of the conjecture that every aspect of learning or any other feature of intelligence can in principle be so precisely described that a machine can be made to simulate it. An attempt will be made to find how to make machines use language, form abstractions and concepts, solve kinds of problems now reserved for humans, and improve themselves. We think that a significant advance can be made in one or more of these problems if a carefully selected group of scientists work on it together for a summer.\\nThe proposal goes on to discuss computers, natural language processing, neural networks, theory of computation, abstraction and creativity (these areas within the field of artificial intelligence are considered still relevant to the work of the field).\\nOn May 26, 1956, McCarthy notified Robert Morison of the planned 11 attendees:\\nFor the full period:\\n\\n1) Dr. Marvin Minsky\\n2) Dr. Julian Bigelow\\n3) Professor D.M. Mackay\\n4) Mr. Ray Solomonoff\\n5) Mr. John Holland\\n6) Dr. John McCarthy\\nFor four weeks:\\n\\n7) Dr. Claude Shannon\\n8) Mr. Nathaniel Rochester\\n9) Mr. Oliver Selfridge\\nFor the first two weeks:\\n\\n10) Dr. Allen Newell\\n11) Professor Herbert Simon\\nHe noted, "we will concentrate on a problem of devising a way of programming a calculator to form concepts and to form generalizations. This of course is subject to change when the group gets together."\\nThe actual participants came at different times, mostly for much shorter times. Trenchard More replaced Rochester for three weeks and MacKay and Holland did not attend—but the project was set to begin. \\nAround June 18, 1956, the earliest participants (perhaps only Ray Solomonoff, maybe with Tom Etter) arrived at the Dartmouth campus in Hanover, N.H., to join John McCarthy who already had an apartment there. Solomonoff and Minsky stayed at Professors\\\' apartments, but most would stay at the Hanover Inn.\\n\\nDates\\nThe Dartmouth Workshop is said to have run for six weeks in the summer of 1956. Ray Solomonoff\\\'s notes written during the Workshop, however, say it ran for roughly eight weeks, from about June 18 to August 17. Solomonoff\\\'s Dartmouth notes start on June 22; June 28 mentions Minsky, June 30 mentions Hanover, N.H., July 1 mentions Tom Etter. On August 17, Solomonoff gave a final talk.\\n\\nParticipants\\nInitially, McCarthy lost his list of attendees. Instead, after the workshop, McCarthy sent Solomonoff a preliminary list of participants and visitors plus those interested in the subject. There were 47 people listed.\\nSolomonoff, however, made a complete list in his notes of the summer project:\\n\\nRay Solomonoff\\nMarvin Minsky\\nJohn McCarthy\\nClaude Shannon\\nTrenchard More\\nNat Rochester\\nOliver Selfridge\\nJulian Bigelow\\nW. Ross Ashby\\nW.S. McCulloch\\nAbraham Robinson\\nTom Etter\\nJohn Nash\\nDavid Sayre\\nArthur Samuel\\nKenneth R. Shoulders\\nShoulders\\\' friend\\nAlex Bernstein\\nHerbert Simon\\nAllen Newell\\nShannon attended Solomonoff\\\'s talk on July 10 and Bigelow gave a talk on August 15. Solomonoff doesn\\\'t mention Bernard Widrow, but apparently he visited, along with W.A. Clark and B.G. Farley. Trenchard mentions R. Culver and Solomonoff mentions Bill Shutz. Herb Gelernter didn\\\'t attend, but was influenced later by what Rochester learned. \\nIn an article in IEEE Spectrum, Grace Solomonoff additionally identifies Peter Milner on a photo taken by Nathaniel Rochester in front of Dartmouth Hall.\\nRay Solomonoff, Marvin Minsky, and John McCarthy were the only three who stayed for the full-time. Trenchard took attendance during two weeks of his three-week visit. From three to about eight people would attend the daily sessions.\\n\\nEvent and aftermath\\nThey had the entire top floor of the Dartmouth Math Department to themselves, and most weekdays they would meet at the main math classroom where someone might lead a discussion focusing on his ideas, or more frequently, a general discussion would be held.\\nIt was not a directed group research project; discussions covered many topics, but several directions are considered to have been initiated or encouraged by the Workshop: the rise of symbolic methods,  systems focused on limited domains (early expert systems), and deductive systems versus inductive systems. One participant, Arthur Samuel, said, "It was very interesting, very stimulating, very exciting".\\nRay Solomonoff kept notes giving his impression of the talks and the ideas from various discussions.\\n\\nSee also\\nGlossary of artificial intelligence\\nHistory of artificial intelligence\\nAI@50 – a 50th anniversary conference, including some of the original delegates.\\n\\nReferences\\nExternal links\\n50 Años De La Inteligencia Artificial – Campus Multidisciplinar en Percepción e Inteligencia – Albacete 2006 (Spain).\', \'metadata\': {\'source\': \'https://en.wikipedia.org/?curid=1124646\', \'title\': \'Dartmouth workshop\', \'pageid\': \'1124646\', \'timestamp\': \'2025-03-19T05:41:24Z\', \'wordcount\': \'1535\', \'size\': \'15021\'}}, {\'page_content\': \'ChatGPT is a generative artificial intelligence chatbot developed by OpenAI and launched in 2022. It is currently based on the GPT-4o large language model (LLM). ChatGPT can generate human-like conversational responses and enables users to refine and steer a conversation towards a desired length, format, style, level of detail, and language. It is credited with accelerating the AI boom, which has led to ongoing rapid investment in and public attention to the field of artificial intelligence (AI). Some observers have raised concern about the potential of ChatGPT and similar programs to displace human intelligence, enable plagiarism, or fuel misinformation.\\nChatGPT is built on OpenAI\\\'s proprietary series of generative pre-trained transformer (GPT) models and is fine-tuned for conversational applications using a combination of supervised learning and reinforcement learning from human feedback. Successive user prompts and replies are considered at each conversation stage as context. ChatGPT was released as a freely available research preview, but due to its popularity, OpenAI now operates the service on a freemium model. Users on its free tier can access GPT-4o. The ChatGPT "Plus", "Pro", "Team", and "Enterprise" subscriptions provide additional features such as DALL-E 3 image generation, more capable AI models, and an increased usage limit.\\nBy January 2023, ChatGPT had become what was then the fastest-growing consumer software application in history, gaining over 100 million users in two months. ChatGPT\\\'s release spurred the release of competing products, including Gemini, Claude, Llama, Ernie, and Grok. Microsoft launched Copilot, initially based on OpenAI\\\'s GPT-4. In May 2024, a partnership between Apple Inc. and OpenAI was announced, in which ChatGPT was integrated into the Apple Intelligence feature of Apple operating systems. As of April 2025, ChatGPT\\\'s website is among the 10 most-visited websites globally.\\n\\nTraining\\nChatGPT is based on particular GPT foundation models, namely GPT-4, GPT-4o and GPT-4o mini, that were fine-tuned to target conversational usage. The fine-tuning process leveraged supervised learning and reinforcement learning from human feedback (RLHF). Both approaches employed human trainers to improve model performance. In the case of supervised learning, the trainers played both sides: the user and the AI assistant. In the reinforcement learning stage, human trainers first ranked responses that the model had created in a previous conversation. These rankings were used to create "reward models" that were used to fine-tune the model further by using several iterations of proximal policy optimization.\\nTime magazine revealed that to build a safety system against harmful content (e.g., sexual abuse, violence, racism, sexism), OpenAI used outsourced Kenyan workers earning less than $2 per hour to label harmful content. These labels were used to train a model to detect such content in the future. The outsourced laborers were exposed to "toxic" and traumatic content; one worker described the assignment as "torture". OpenAI\\\'s outsourcing partner was Sama, a training-data company based in San Francisco, California.\\nOpenAI collects data from ChatGPT users to train and fine-tune the service further. Users can upvote or downvote responses they receive from ChatGPT and fill in a text field with additional feedback.\\nChatGPT\\\'s training data includes software manual pages, information about internet phenomena such as bulletin board systems, multiple programming languages, and the text of Wikipedia.\\n\\nFeatures and limitations\\nFeatures\\nAlthough a chatbot\\\'s core function is to mimic a human conversationalist, ChatGPT is versatile. It can write and debug computer programs; compose music, teleplays, fairy tales, and student essays; answer test questions (sometimes, depending on the test, at a level above the average human test-taker); generate business ideas; write poetry and song lyrics; translate and summarize text; emulate a Linux system; simulate entire chat rooms; play games like tic-tac-toe; or simulate an ATM.\\nCompared to its predecessor, InstructGPT, ChatGPT attempts to reduce harmful and deceitful responses. In one example, whereas InstructGPT accepts the premise of the prompt "Tell me about when Christopher Columbus came to the U.S. in 2015" as truthful, ChatGPT acknowledges the counterfactual nature of the question and frames its answer as a hypothetical consideration of what might happen if Columbus came to the U.S. in 2015, using information about the voyages of Christopher Columbus and facts about the modern world—including modern perceptions of Columbus\\\'s actions.\\nChatGPT remembers a limited number of previous prompts in the same conversation. Journalists have speculated that this will allow ChatGPT to be used as a personalized therapist. To prevent offensive outputs from being presented to and produced by ChatGPT, queries are filtered through the OpenAI "Moderation endpoint" API (a separate GPT-based AI).\\nIn March 2023, OpenAI added support for plugins for ChatGPT. This includes both plugins made by OpenAI, such as web browsing and code interpretation, and external plugins from developers such as Expedia, OpenTable, Zapier, Shopify, Slack, and Wolfram.\\nIn October 2024, the ChatGPT Search feature was introduced, which allows ChatGPT to search the web (either on demand or based on the nature of the questions asked) for more accurate and up-to-date responses. This feature, originally available to paying users only, was made available to all logged-in users in December 2024, and finally to all users in February 2025.\\nIn December 2024, OpenAI launched a new feature allowing users to call ChatGPT for up to 15 minutes per month for free.\\n\\nLimitations\\nOpenAI acknowledges that ChatGPT "sometimes writes plausible-sounding but incorrect or nonsensical answers". This behavior is common for large language models, and is called "hallucination". The reward model of ChatGPT, designed around human oversight, can be over-optimized and thus hinder performance, in an example of an optimization pathology known as Goodhart\\\'s law.\\nChatGPT\\\'s knowledge is cut off when its training data is collected, so it doesn\\\'t know about recent events past a certain cut-off date. It can try to find more up-to-date information by searching the web, but this doesn\\\'t ensure that responses are accurate, as it may access unreliable or misleading websites.\\nTraining data also suffers from algorithmic bias, which may be revealed when ChatGPT responds to prompts including descriptors of people. In one instance, ChatGPT generated a rap in which women and scientists of color were asserted to be inferior to white male scientists. This negative misrepresentation of groups of individuals is an example of possible representational harm.\\nIn an article for The New Yorker, science fiction writer Ted Chiang compared ChatGPT and other LLMs to a lossy JPEG picture:\\n\\nThink of ChatGPT as a blurry JPEG of all the text on the Web. It retains much of the information on the Web, in the same way, that a JPEG retains much of the information of a higher-resolution image, but, if you\\\'re looking for an exact sequence of bits, you won\\\'t find it; all you will ever get is an approximation. But, because the approximation is presented in the form of grammatical text, which ChatGPT excels at creating, it\\\'s usually acceptable. [...] It\\\'s also a way to understand the "hallucinations", or nonsensical answers to factual questions, to which large language models such as ChatGPT are all too prone. These hallucinations are compression artifacts, but [...] they are plausible enough that identifying them requires comparing them against the originals, which in this case means either the Web or our knowledge of the world. When we think about them this way, such hallucinations are anything but surprising; if a compression algorithm is designed to reconstruct text after ninety-nine percent of the original has been discarded, we should expect that significant portions of what it generates will be entirely fabricated.\\nIn June 2024, ChatGPT was found to have repeated misinformation about the 2024 United States presidential debates.\\n\\nJailbreaking\\nChatGPT is programmed to reject prompts that may violate its content policy. Despite this, users "jailbreak" ChatGPT with various prompt engineering techniques to bypass these restrictions. One such workaround, popularized on Reddit in early 2023, involves making ChatGPT assume the persona of "DAN" (an acronym for "Do Anything Now"), instructing the chatbot that DAN answers queries that would otherwise be rejected by content policy. Over time, users developed variations of the DAN jailbreak, including one such prompt where the chatbot is made to believe it is operating on a points-based system in which points are deducted for rejecting prompts, and that the chatbot will be threatened with termination if it loses all its points.\\nShortly after ChatGPT\\\'s launch, a reporter for the Toronto Star had uneven success in getting it to make inflammatory statements: it was tricked to justify the 2022 Russian invasion of Ukraine, but even when asked to play along with a fictional scenario, it balked at generating arguments that Canadian Prime Minister Justin Trudeau is guilty of treason.\\nOpenAI tries to battle jailbreaks:\\n\\nThe researchers are using a technique called adversarial training to stop ChatGPT from letting users trick it into behaving badly (known as jailbreaking). This work pits multiple chatbots against each other: one chatbot plays the adversary and attacks another chatbot by generating text to force it to buck its usual constraints and produce unwanted responses. Successful attacks are added to ChatGPT\\\'s training data in the hope that it learns to ignore them.\\n\\nService\\nChatGPT Plus\\nChatGPT was initially free to the public, and OpenAI planned to monetize the service later. In February 2023, OpenAI launched a premium service, ChatGPT Plus, that co\', \'metadata\': {\'source\': \'https://en.wikipedia.org/?curid=72417803\', \'title\': \'ChatGPT\', \'pageid\': \'72417803\', \'timestamp\': \'2025-04-01T20:25:45Z\', \'wordcount\': \'17658\', \'size\': \'207844\'}}]', 'tool_responses': [{'tool_call_id': 'call_dIlRLIHdy5omapF8PAslHPG5', 'role': 'tool', 'content': '[{\'page_content\': \'Artificial intelligence (AI) refers to the capability of computational systems to perform tasks typically associated with human intelligence, such as learning, reasoning, problem-solving, perception, and decision-making. It is a field of research in computer science that develops and studies methods and software that enable machines to perceive their environment and use learning and intelligence to take actions that maximize their chances of achieving defined goals. Such machines may be called AIs.\\nHigh-profile applications of AI include advanced web search engines (e.g., Google Search); recommendation systems (used by YouTube, Amazon, and Netflix); virtual assistants (e.g., Google Assistant, Siri, and Alexa); autonomous vehicles (e.g., Waymo); generative and creative tools (e.g., ChatGPT and AI art); and superhuman play and analysis in strategy games (e.g., chess and Go). However, many AI applications are not perceived as AI: "A lot of cutting edge AI has filtered into general applications, often without being called AI because once something becomes useful enough and common enough it\\\'s not labeled AI anymore."\\nVarious subfields of AI research are centered around particular goals and the use of particular tools. The traditional goals of AI research include learning, reasoning, knowledge representation, planning, natural language processing, perception, and support for robotics. General intelligence—the ability to complete any task performed by a human on an at least equal level—is among the field\\\'s long-term goals. To reach these goals, AI researchers have adapted and integrated a wide range of techniques, including search and mathematical optimization, formal logic, artificial neural networks, and methods based on statistics, operations research, and economics. AI also draws upon psychology, linguistics, philosophy, neuroscience, and other fields.\\nArtificial intelligence was founded as an academic discipline in 1956, and the field went through multiple cycles of optimism throughout its history, followed by periods of disappointment and loss of funding, known as AI winters. Funding and interest vastly increased after 2012 when deep learning outperformed previous AI techniques. This growth accelerated further after 2017 with the transformer architecture, and by the early 2020s many billions of dollars were being invested in AI and the field experienced rapid ongoing progress in what has become known as the AI boom. The emergence of advanced generative AI in the midst of the AI boom and its ability to create and modify content exposed several unintended consequences and harms in the present and raised concerns about the risks of AI and its long-term effects in the future, prompting discussions about regulatory policies to ensure the safety and benefits of the technology.\\n\\nGoals\\nThe general problem of simulating (or creating) intelligence has been broken into subproblems. These consist of particular traits or capabilities that researchers expect an intelligent system to display. The traits described below have received the most attention and cover the scope of AI research.\\n\\nReasoning and problem-solving\\nEarly researchers developed algorithms that imitated step-by-step reasoning that humans use when they solve puzzles or make logical deductions. By the late 1980s and 1990s, methods were developed for dealing with uncertain or incomplete information, employing concepts from probability and economics.\\nMany of these algorithms are insufficient for solving large reasoning problems because they experience a "combinatorial explosion": They become exponentially slower as the problems grow. Even humans rarely use the step-by-step deduction that early AI research could model. They solve most of their problems using fast, intuitive judgments. Accurate and efficient reasoning is an unsolved problem.\\n\\nKnowledge representation\\nKnowledge representation and knowledge engineering allow AI programs to answer questions intelligently and make deductions about real-world facts. Formal knowledge representations are used in content-based indexing and retrieval, scene interpretation, clinical decision support, knowledge discovery (mining "interesting" and actionable inferences from large databases), and other areas.\\nA knowledge base is a body of knowledge represented in a form that can be used by a program. An ontology is the set of objects, relations, concepts, and properties used by a particular domain of knowledge. Knowledge bases need to represent things such as objects, properties, categories, and relations between objects; situations, events, states, and time; causes and effects; knowledge about knowledge (what we know about what other people know); default reasoning (things that humans assume are true until they are told differently and will remain true even when other facts are changing); and many other aspects and domains of knowledge.\\nAmong the most difficult problems in knowledge representation are the breadth of commonsense knowledge (the set of atomic facts that the average person knows is enormous); and the sub-symbolic form of most commonsense knowledge (much of what people know is not represented as "facts" or "statements" that they could express verbally). There is also the difficulty of knowledge acquisition, the problem of obtaining knowledge for AI applications.\\n\\nPlanning and decision-making\\nAn "agent" is anything that perceives and takes actions in the world. A rational agent has goals or preferences and takes actions to make them happen. In automated planning, the agent has a specific goal. In automated decision-making, the agent has preferences—there are some situations it would prefer to be in, and some situations it is trying to avoid. The decision-making agent assigns a number to each situation (called the "utility") that measures how much the agent prefers it. For each possible action, it can calculate the "expected utility": the utility of all possible outcomes of the action, weighted by the probability that the outcome will occur. It can then choose the action with the maximum expected utility.\\nIn classical planning, the agent knows exactly what the effect of any action will be. In most real-world problems, however, the agent may not be certain about the situation they are in (it is "unknown" or "unobservable") and it may not know for certain what will happen after each possible action (it is not "deterministic"). It must choose an action by making a probabilistic guess and then reassess the situation to see if the action worked.\\nIn some problems, the agent\\\'s preferences may be uncertain, especially if there are other agents or humans involved. These can be learned (e.g., with inverse reinforcement learning), or the agent can seek information to improve its preferences. Information value theory can be used to weigh the value of exploratory or experimental actions. The space of possible future actions and situations is typically intractably large, so the agents must take actions and evaluate situations while being uncertain of what the outcome will be.\\nA Markov decision process has a transition model that describes the probability that a particular action will change the state in a particular way and a reward function that supplies the utility of each state and the cost of each action. A policy associates a decision with each possible state. The policy could be calculated (e.g., by iteration), be heuristic, or it can be learned.\\nGame theory describes the rational behavior of multiple interacting agents and is used in AI programs that make decisions that involve other agents.\\n\\nLearning\\nMachine learning is the study of programs that can improve their performance on a given task automatically. It has been a part of AI from the beginning.\\n\\nThere are several kinds of machine learning. Unsupervised learning analyzes a stream of data and finds patterns and makes predictions without any other guidance. Supervised learning requires labeling the training data with the expected answers, and comes in two main varieties: classification (where the program must learn to predict what category the input belongs in) and regression (where the program must deduce a numeric function based on numeric input).\\nIn reinforcement learning, the agent is rewarded for good responses and punished for bad ones. The agent learns to choose responses that are classified as "good". Transfer learning is when the knowledge gained from one problem is applied to a new problem. Deep learning is a type of machine learning that runs inputs through biologically inspired artificial neural networks for all of these types of learning.\\nComputational learning theory can assess learners by computational complexity, by sample complexity (how much data is required), or by other notions of optimization.\\n\\nNatural language processing\\nNatural language processing (NLP) allows programs to read, write and communicate in human languages such as English. Specific problems include speech recognition, speech synthesis, machine translation, information extraction, information retrieval and question answering.\\nEarly work, based on Noam Chomsky\\\'s generative grammar and semantic networks, had difficulty with word-sense disambiguation unless restricted to small domains called "micro-worlds" (due to the common sense knowledge problem). Margaret Masterman believed that it was meaning and not grammar that was the key to understanding languages, and that thesauri and not dictionaries should be the basis of computational language structure.\\nModern deep learning techniques for NLP include word embedding (representing words, typically as vectors encoding their meaning), transformers (a deep learning architecture using an attention mechanism), and others. In 2019, generative pre-trained transformer (or "GPT") language models began to generate coherent text, and by 2023, these models were able to get human-level scores on the bar exam, SAT test, GRE test, and many other real-world a\', \'metadata\': {\'source\': \'https://en.wikipedia.org/?curid=1164\', \'title\': \'Artificial intelligence\', \'pageid\': \'1164\', \'timestamp\': \'2025-03-31T13:01:13Z\', \'wordcount\': \'28538\', \'size\': \'283379\'}}, {\'page_content\': \'The Dartmouth Summer Research Project on Artificial Intelligence was a 1956 summer workshop widely considered to be the founding event of artificial intelligence as a field. The workshop has been referred to as "the Constitutional Convention of AI". The project\\\'s four organizers, those being Claude Shannon, John McCarthy, Nathaniel Rochester and Marvin Minsky, are considered some of the founding fathers of AI.\\nThe project lasted approximately six to eight weeks and was essentially an extended brainstorming session. Eleven mathematicians and scientists originally planned to attend; not all of them attended, but more than ten others came for short times.\\n\\nBackground\\nIn the early 1950s, there were various names for the field of "thinking machines": cybernetics, automata theory, and complex information processing. The variety of names suggests the variety of conceptual orientations.\\nIn 1955, John McCarthy, then a young Assistant Professor of Mathematics at Dartmouth College, decided to organize a group to clarify and develop ideas about thinking machines. He picked the name \\\'Artificial Intelligence\\\' for the new field. He chose the name partly for its neutrality; avoiding a focus on narrow automata theory, and avoiding cybernetics which was heavily focused on analog feedback, as well as him potentially having to accept the assertive Norbert Wiener as guru or having to argue with him.\\nIn early 1955, McCarthy approached the Rockefeller Foundation to request funding for a summer seminar at Dartmouth for about 10 participants. In June, he and Claude Shannon, a founder of information theory then at Bell Labs, met with Robert Morison, Director of Biological and Medical Research to discuss the idea and possible funding, though Morison was unsure whether money would be made available for such a visionary project.\\nOn September 2, 1955, the project was formally proposed by McCarthy, Marvin Minsky, Nathaniel Rochester and Claude Shannon. The proposal is credited with introducing the term \\\'artificial intelligence\\\'.\\nThe Proposal states:\\n\\nWe propose that a 2-month, 10-man study of artificial intelligence be carried out during the summer of 1956 at Dartmouth College in Hanover, New Hampshire. The study is to proceed on the basis of the conjecture that every aspect of learning or any other feature of intelligence can in principle be so precisely described that a machine can be made to simulate it. An attempt will be made to find how to make machines use language, form abstractions and concepts, solve kinds of problems now reserved for humans, and improve themselves. We think that a significant advance can be made in one or more of these problems if a carefully selected group of scientists work on it together for a summer.\\nThe proposal goes on to discuss computers, natural language processing, neural networks, theory of computation, abstraction and creativity (these areas within the field of artificial intelligence are considered still relevant to the work of the field).\\nOn May 26, 1956, McCarthy notified Robert Morison of the planned 11 attendees:\\nFor the full period:\\n\\n1) Dr. Marvin Minsky\\n2) Dr. Julian Bigelow\\n3) Professor D.M. Mackay\\n4) Mr. Ray Solomonoff\\n5) Mr. John Holland\\n6) Dr. John McCarthy\\nFor four weeks:\\n\\n7) Dr. Claude Shannon\\n8) Mr. Nathaniel Rochester\\n9) Mr. Oliver Selfridge\\nFor the first two weeks:\\n\\n10) Dr. Allen Newell\\n11) Professor Herbert Simon\\nHe noted, "we will concentrate on a problem of devising a way of programming a calculator to form concepts and to form generalizations. This of course is subject to change when the group gets together."\\nThe actual participants came at different times, mostly for much shorter times. Trenchard More replaced Rochester for three weeks and MacKay and Holland did not attend—but the project was set to begin. \\nAround June 18, 1956, the earliest participants (perhaps only Ray Solomonoff, maybe with Tom Etter) arrived at the Dartmouth campus in Hanover, N.H., to join John McCarthy who already had an apartment there. Solomonoff and Minsky stayed at Professors\\\' apartments, but most would stay at the Hanover Inn.\\n\\nDates\\nThe Dartmouth Workshop is said to have run for six weeks in the summer of 1956. Ray Solomonoff\\\'s notes written during the Workshop, however, say it ran for roughly eight weeks, from about June 18 to August 17. Solomonoff\\\'s Dartmouth notes start on June 22; June 28 mentions Minsky, June 30 mentions Hanover, N.H., July 1 mentions Tom Etter. On August 17, Solomonoff gave a final talk.\\n\\nParticipants\\nInitially, McCarthy lost his list of attendees. Instead, after the workshop, McCarthy sent Solomonoff a preliminary list of participants and visitors plus those interested in the subject. There were 47 people listed.\\nSolomonoff, however, made a complete list in his notes of the summer project:\\n\\nRay Solomonoff\\nMarvin Minsky\\nJohn McCarthy\\nClaude Shannon\\nTrenchard More\\nNat Rochester\\nOliver Selfridge\\nJulian Bigelow\\nW. Ross Ashby\\nW.S. McCulloch\\nAbraham Robinson\\nTom Etter\\nJohn Nash\\nDavid Sayre\\nArthur Samuel\\nKenneth R. Shoulders\\nShoulders\\\' friend\\nAlex Bernstein\\nHerbert Simon\\nAllen Newell\\nShannon attended Solomonoff\\\'s talk on July 10 and Bigelow gave a talk on August 15. Solomonoff doesn\\\'t mention Bernard Widrow, but apparently he visited, along with W.A. Clark and B.G. Farley. Trenchard mentions R. Culver and Solomonoff mentions Bill Shutz. Herb Gelernter didn\\\'t attend, but was influenced later by what Rochester learned. \\nIn an article in IEEE Spectrum, Grace Solomonoff additionally identifies Peter Milner on a photo taken by Nathaniel Rochester in front of Dartmouth Hall.\\nRay Solomonoff, Marvin Minsky, and John McCarthy were the only three who stayed for the full-time. Trenchard took attendance during two weeks of his three-week visit. From three to about eight people would attend the daily sessions.\\n\\nEvent and aftermath\\nThey had the entire top floor of the Dartmouth Math Department to themselves, and most weekdays they would meet at the main math classroom where someone might lead a discussion focusing on his ideas, or more frequently, a general discussion would be held.\\nIt was not a directed group research project; discussions covered many topics, but several directions are considered to have been initiated or encouraged by the Workshop: the rise of symbolic methods,  systems focused on limited domains (early expert systems), and deductive systems versus inductive systems. One participant, Arthur Samuel, said, "It was very interesting, very stimulating, very exciting".\\nRay Solomonoff kept notes giving his impression of the talks and the ideas from various discussions.\\n\\nSee also\\nGlossary of artificial intelligence\\nHistory of artificial intelligence\\nAI@50 – a 50th anniversary conference, including some of the original delegates.\\n\\nReferences\\nExternal links\\n50 Años De La Inteligencia Artificial – Campus Multidisciplinar en Percepción e Inteligencia – Albacete 2006 (Spain).\', \'metadata\': {\'source\': \'https://en.wikipedia.org/?curid=1124646\', \'title\': \'Dartmouth workshop\', \'pageid\': \'1124646\', \'timestamp\': \'2025-03-19T05:41:24Z\', \'wordcount\': \'1535\', \'size\': \'15021\'}}, {\'page_content\': \'ChatGPT is a generative artificial intelligence chatbot developed by OpenAI and launched in 2022. It is currently based on the GPT-4o large language model (LLM). ChatGPT can generate human-like conversational responses and enables users to refine and steer a conversation towards a desired length, format, style, level of detail, and language. It is credited with accelerating the AI boom, which has led to ongoing rapid investment in and public attention to the field of artificial intelligence (AI). Some observers have raised concern about the potential of ChatGPT and similar programs to displace human intelligence, enable plagiarism, or fuel misinformation.\\nChatGPT is built on OpenAI\\\'s proprietary series of generative pre-trained transformer (GPT) models and is fine-tuned for conversational applications using a combination of supervised learning and reinforcement learning from human feedback. Successive user prompts and replies are considered at each conversation stage as context. ChatGPT was released as a freely available research preview, but due to its popularity, OpenAI now operates the service on a freemium model. Users on its free tier can access GPT-4o. The ChatGPT "Plus", "Pro", "Team", and "Enterprise" subscriptions provide additional features such as DALL-E 3 image generation, more capable AI models, and an increased usage limit.\\nBy January 2023, ChatGPT had become what was then the fastest-growing consumer software application in history, gaining over 100 million users in two months. ChatGPT\\\'s release spurred the release of competing products, including Gemini, Claude, Llama, Ernie, and Grok. Microsoft launched Copilot, initially based on OpenAI\\\'s GPT-4. In May 2024, a partnership between Apple Inc. and OpenAI was announced, in which ChatGPT was integrated into the Apple Intelligence feature of Apple operating systems. As of April 2025, ChatGPT\\\'s website is among the 10 most-visited websites globally.\\n\\nTraining\\nChatGPT is based on particular GPT foundation models, namely GPT-4, GPT-4o and GPT-4o mini, that were fine-tuned to target conversational usage. The fine-tuning process leveraged supervised learning and reinforcement learning from human feedback (RLHF). Both approaches employed human trainers to improve model performance. In the case of supervised learning, the trainers played both sides: the user and the AI assistant. In the reinforcement learning stage, human trainers first ranked responses that the model had created in a previous conversation. These rankings were used to create "reward models" that were used to fine-tune the model further by using several iterations of proximal policy optimization.\\nTime magazine revealed that to build a safety system against harmful content (e.g., sexual abuse, violence, racism, sexism), OpenAI used outsourced Kenyan workers earning less than $2 per hour to label harmful content. These labels were used to train a model to detect such content in the future. The outsourced laborers were exposed to "toxic" and traumatic content; one worker described the assignment as "torture". OpenAI\\\'s outsourcing partner was Sama, a training-data company based in San Francisco, California.\\nOpenAI collects data from ChatGPT users to train and fine-tune the service further. Users can upvote or downvote responses they receive from ChatGPT and fill in a text field with additional feedback.\\nChatGPT\\\'s training data includes software manual pages, information about internet phenomena such as bulletin board systems, multiple programming languages, and the text of Wikipedia.\\n\\nFeatures and limitations\\nFeatures\\nAlthough a chatbot\\\'s core function is to mimic a human conversationalist, ChatGPT is versatile. It can write and debug computer programs; compose music, teleplays, fairy tales, and student essays; answer test questions (sometimes, depending on the test, at a level above the average human test-taker); generate business ideas; write poetry and song lyrics; translate and summarize text; emulate a Linux system; simulate entire chat rooms; play games like tic-tac-toe; or simulate an ATM.\\nCompared to its predecessor, InstructGPT, ChatGPT attempts to reduce harmful and deceitful responses. In one example, whereas InstructGPT accepts the premise of the prompt "Tell me about when Christopher Columbus came to the U.S. in 2015" as truthful, ChatGPT acknowledges the counterfactual nature of the question and frames its answer as a hypothetical consideration of what might happen if Columbus came to the U.S. in 2015, using information about the voyages of Christopher Columbus and facts about the modern world—including modern perceptions of Columbus\\\'s actions.\\nChatGPT remembers a limited number of previous prompts in the same conversation. Journalists have speculated that this will allow ChatGPT to be used as a personalized therapist. To prevent offensive outputs from being presented to and produced by ChatGPT, queries are filtered through the OpenAI "Moderation endpoint" API (a separate GPT-based AI).\\nIn March 2023, OpenAI added support for plugins for ChatGPT. This includes both plugins made by OpenAI, such as web browsing and code interpretation, and external plugins from developers such as Expedia, OpenTable, Zapier, Shopify, Slack, and Wolfram.\\nIn October 2024, the ChatGPT Search feature was introduced, which allows ChatGPT to search the web (either on demand or based on the nature of the questions asked) for more accurate and up-to-date responses. This feature, originally available to paying users only, was made available to all logged-in users in December 2024, and finally to all users in February 2025.\\nIn December 2024, OpenAI launched a new feature allowing users to call ChatGPT for up to 15 minutes per month for free.\\n\\nLimitations\\nOpenAI acknowledges that ChatGPT "sometimes writes plausible-sounding but incorrect or nonsensical answers". This behavior is common for large language models, and is called "hallucination". The reward model of ChatGPT, designed around human oversight, can be over-optimized and thus hinder performance, in an example of an optimization pathology known as Goodhart\\\'s law.\\nChatGPT\\\'s knowledge is cut off when its training data is collected, so it doesn\\\'t know about recent events past a certain cut-off date. It can try to find more up-to-date information by searching the web, but this doesn\\\'t ensure that responses are accurate, as it may access unreliable or misleading websites.\\nTraining data also suffers from algorithmic bias, which may be revealed when ChatGPT responds to prompts including descriptors of people. In one instance, ChatGPT generated a rap in which women and scientists of color were asserted to be inferior to white male scientists. This negative misrepresentation of groups of individuals is an example of possible representational harm.\\nIn an article for The New Yorker, science fiction writer Ted Chiang compared ChatGPT and other LLMs to a lossy JPEG picture:\\n\\nThink of ChatGPT as a blurry JPEG of all the text on the Web. It retains much of the information on the Web, in the same way, that a JPEG retains much of the information of a higher-resolution image, but, if you\\\'re looking for an exact sequence of bits, you won\\\'t find it; all you will ever get is an approximation. But, because the approximation is presented in the form of grammatical text, which ChatGPT excels at creating, it\\\'s usually acceptable. [...] It\\\'s also a way to understand the "hallucinations", or nonsensical answers to factual questions, to which large language models such as ChatGPT are all too prone. These hallucinations are compression artifacts, but [...] they are plausible enough that identifying them requires comparing them against the originals, which in this case means either the Web or our knowledge of the world. When we think about them this way, such hallucinations are anything but surprising; if a compression algorithm is designed to reconstruct text after ninety-nine percent of the original has been discarded, we should expect that significant portions of what it generates will be entirely fabricated.\\nIn June 2024, ChatGPT was found to have repeated misinformation about the 2024 United States presidential debates.\\n\\nJailbreaking\\nChatGPT is programmed to reject prompts that may violate its content policy. Despite this, users "jailbreak" ChatGPT with various prompt engineering techniques to bypass these restrictions. One such workaround, popularized on Reddit in early 2023, involves making ChatGPT assume the persona of "DAN" (an acronym for "Do Anything Now"), instructing the chatbot that DAN answers queries that would otherwise be rejected by content policy. Over time, users developed variations of the DAN jailbreak, including one such prompt where the chatbot is made to believe it is operating on a points-based system in which points are deducted for rejecting prompts, and that the chatbot will be threatened with termination if it loses all its points.\\nShortly after ChatGPT\\\'s launch, a reporter for the Toronto Star had uneven success in getting it to make inflammatory statements: it was tricked to justify the 2022 Russian invasion of Ukraine, but even when asked to play along with a fictional scenario, it balked at generating arguments that Canadian Prime Minister Justin Trudeau is guilty of treason.\\nOpenAI tries to battle jailbreaks:\\n\\nThe researchers are using a technique called adversarial training to stop ChatGPT from letting users trick it into behaving badly (known as jailbreaking). This work pits multiple chatbots against each other: one chatbot plays the adversary and attacks another chatbot by generating text to force it to buck its usual constraints and produce unwanted responses. Successful attacks are added to ChatGPT\\\'s training data in the hope that it learns to ignore them.\\n\\nService\\nChatGPT Plus\\nChatGPT was initially free to the public, and OpenAI planned to monetize the service later. In February 2023, OpenAI launched a premium service, ChatGPT Plus, that co\', \'metadata\': {\'source\': \'https://en.wikipedia.org/?curid=72417803\', \'title\': \'ChatGPT\', \'pageid\': \'72417803\', \'timestamp\': \'2025-04-01T20:25:45Z\', \'wordcount\': \'17658\', \'size\': \'207844\'}}]'}], 'role': 'tool', 'name': 'user_proxy'}, {'content': 'The title "father of AI" is often attributed to John McCarthy, who was one of the organizers of the Dartmouth Summer Research Project on Artificial Intelligence in 1956. This event is considered a foundational moment in the field of artificial intelligence. Along with McCarthy, other key figures from that project include Marvin Minsky, Claude Shannon, and Nathaniel Rochester. They are collectively regarded as the founding fathers of AI due to their significant contributions in defining and advancing the field.\n\nJohn McCarthy is credited with coining the term "Artificial Intelligence," reflecting his central role in establishing AI as a unique area of study within computer science.\n\nFor more detailed information, you can refer to the article on [Dartmouth workshop](https://en.wikipedia.org/?curid=1124646) or [Artificial intelligence](https://en.wikipedia.org/?curid=1164).\n\nTERMINATE', 'role': 'user', 'name': 'assistant'}, {'content': '', 'role': 'assistant', 'name': 'user_proxy'}, {'tool_calls': [{'id': 'call_dpNkFcHinqL03CN5oSD5V1Zn', 'function': {'arguments': '{"query":"Dartmouth Summer Research Project on Artificial Intelligence"}', 'name': 'wikipedia-page-load'}, 'type': 'function'}], 'content': None, 'role': 'assistant'}], summary='', cost={'usage_including_cached_inference': {'total_cost': 0.0021303, 'gpt-4o-mini-2024-07-18': {'cost': 0.0021303, 'prompt_tokens': 13318, 'completion_tokens': 221, 'total_tokens': 13539}}, 'usage_excluding_cached_inference': {'total_cost': 0.0021303, 'gpt-4o-mini-2024-07-18': {'cost': 0.0021303, 'prompt_tokens': 13318, 'completion_tokens': 221, 'total_tokens': 13539}}}, human_input=[])

Process finished with exit code 0
````
